package fpmon.stats;

import info.monitorenter.gui.chart.*;
import java.awt.Color;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComponent;
import org.hyperic.sigar.CpuInfo;
import org.hyperic.sigar.CpuPerc;
import org.hyperic.sigar.SigarException;
import org.hyperic.sigar.SigarProxy;

/**
 * CPU use.
 *
 * @author Miles Asvachin
 */
public final class CpuStatCollector extends ChartStatCollector
{
	private final ITrace2D lineTrace;

	{
		title = "CPU";
		traceColor = Color.RED;
	}
	
	/**
	 * @param container container in which this collector will display its data
	 * @param updatePeriod time in milliseconds between updates.
	 */
	public CpuStatCollector(final JComponent container, final long updatePeriod, final SigarProxy sigar)
	{
		container.setLayout(new BoxLayout(container, BoxLayout.X_AXIS));
		container.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, rightBorder));
		container.setBackground(backgroundColor);
		
		try
		{
			final CpuInfo cpuInfo = sigar.getCpuInfoList()[0];
			title += String.format(" (%s, %sMHz)", cpuInfo.getModel(), cpuInfo.getMhz());
		}
		catch(SigarException ex)
		{
			Logger.getLogger(CpuStatCollector.class.getName()).log(Level.WARNING, "Couldn't get CPU info", ex);
		}

		final Chart2D lineChart = createLineChart(title, backgroundColor, foregroundColor);
		axisTime(lineChart.getAxisX(), timeAxisFormat);
		axisPercent(lineChart.getAxisY());
		lineTrace = addLineTrace(lineChart, traceSize, "Used: ", traceColor, fillAlpha);
		container.add(lineChart);
		initLineTrace(lineTrace, updatePeriod);
	}
	
	@Override
	protected void update(final SigarProxy sigar)
	{
		try
		{
			final CpuPerc perc = sigar.getCpuPerc();
			final double cpuPercent = (1.0 - perc.getIdle()) * 100.0;
			final ITracePoint2D point = new TracePoint2D(System.currentTimeMillis(), cpuPercent);

			lineTrace.addPoint(point);
			lineTrace.setName("Used: " + Math.round(cpuPercent) + "%");
		}
		catch(SigarException ex)
		{
			Logger.getLogger(CpuStatCollector.class.getName()).log(Level.WARNING, "Couldn't get CPU info", ex);
		}
	}
}
